package com.example.zxweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.example.zxweb.common.api.vo.Result;
import com.example.zxweb.common.constant.enums.IotApiEnum;
import com.example.zxweb.utils.AssertUtils;
import com.example.zxweb.utils.IotUtils;
import com.example.zxweb.vo.QueryCelueListVO;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * @Description
 * @Author ZhouWenTao
 * @Date 2023/9/12 10:28
 */
@RestController
@RequestMapping("/gateway")
@Slf4j
@Api(tags = "网关设备管理")
public class GatewayController {
    //网关设备
    private static final List<String> gatewayDevIdList=new ArrayList<>(Arrays.asList("0cefafd605f7","0cefafd295a4"));
    /**
     * 获取网关策略列表
     * @param queryCelueListVO 入参
     * @return 结果
     */
    @GetMapping(value = "/celueListQuery")
    public Result<?> celueListQuery(QueryCelueListVO queryCelueListVO){
        String devid = queryCelueListVO.getDevid();
        AssertUtils.notEmpty(devid,"请输入-[devid]");
        String format = String.format("{\"serial\":\"%s\",\"productId\":\"\",\"methodName\":\"celueListQuery\",\"inputData\":{\"devid\":\"%s\"}}", devid,devid);
        JSONObject requestBody = JSONObject.parseObject(format);
        JSONObject responseBody = IotUtils.postApi(IotApiEnum.getPathByText("向设备发送方法"), requestBody);
        return jsonObjectToResult(responseBody);
    }


    public static Result<?> jsonObjectToResult(JSONObject jsonObject) {
        Integer code = jsonObject.getInteger("code");
        String message = jsonObject.getString("message");
        String data = jsonObject.getString("data");
        if (code!=0) {
            return Result.error(code, StringUtils.isEmpty(message)?data:message);
        }
        if (StringUtils.isEmpty(message)) {
            return Result.OK(jsonObject.getJSONObject("data"));
        }
        return Result.OK(message);
    }
}
